import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

//redering svg tag from html
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollors 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " $" ;

//creating chart
const render = data => {
  const pieData = pie().sort(null).value(d=>d.Cost_Per_Month_Premium)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  //appending svg
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Cost_Per_Month_Premium))
  	.on("mouseover", d => console.log(d.data.Cost_Per_Month_Premium));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each Country as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.Cost_Per_Month_Premium));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.Cost_Per_Month_Premium));
}

// url of my data giest

const csvUrl =
 'https://gist.githubusercontent.com/Tejaswicmandava/843a4eae8fee8cfbbccebd61df4ce184/raw/e7a052cff81b4572569f2b284c250358de040495/netflix%2520price%2520in%2520different%2520countries-1.csv'
//Load the data and display Premium cost of netflix 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.Cost_Per_Month_Premium-data1.Cost_Per_Month_Basic);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});